==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.server/src/com/openexchange/server/osgi/ModuleSpecificServiceTracker.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.server.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTracker;
import com.openexchange.server.impl.Constants;


/**
 * {@link ModuleSpecificServiceTracker}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 *
 */
public class ModuleSpecificServiceTracker<T> extends ServiceTracker {

    public ModuleSpecificServiceTracker(BundleContext context, Class<T> toTrack) {
        super(context, toTrack.getName(), null);
    }

    @Override
    public Object addingService(ServiceReference reference) {
        T tracked = (T) context.getService(reference);
        Object property = reference.getProperty(Constants.OX_MODULE);
        int module = atoi(property);
        addingService(module, tracked, reference);
        return tracked;
    }

    @Override
    public void modifiedService(ServiceReference reference, Object service) {
        T tracked = (T) getService(reference);
        Object property = reference.getProperty(Constants.OX_MODULE);
        int module = atoi(property);
        modifiedService(module, tracked, reference);
    }


    @Override
    public void removedService(ServiceReference reference, Object service) {
        T tracked = (T) getService(reference);
        Object property = reference.getProperty(Constants.OX_MODULE);
        int module = atoi(property);
        removedService(module, tracked, reference);
        context.ungetService(reference);
    }

    protected int atoi(Object property) {
        if(Integer.class.isInstance(property)) {
            return (Integer) property;
        }
        return Integer.parseInt(property.toString());
    }

    public void removedService(int module, T tracked, ServiceReference reference) {
        // TODO Auto-generated method stub

    }

    public void addingService(int module, T tracked, ServiceReference reference) {
        // TODO Auto-generated method stub

    }

    public void modifiedService(int module, T tracked, ServiceReference reference) {
        // TODO Auto-generated method stub

    }


}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.server/src/com/openexchange/server/osgi/ModuleSpecificServiceTracker.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.server.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTracker;
import com.openexchange.server.impl.Constants;


/**
 * {@link ModuleSpecificServiceTracker}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 *
 */
public class ModuleSpecificServiceTracker<T> extends ServiceTracker {

    public ModuleSpecificServiceTracker(BundleContext context, Class<T> toTrack) {
        super(context, toTrack.getName(), null);
    }

    @Override
    public Object addingService(ServiceReference reference) {
        T tracked = (T) context.getService(reference);
        Object property = reference.getProperty(Constants.OX_MODULE);
        int module = atoi(property);
        addingService(module, tracked, reference);
        return tracked;
    }

    @Override
    public void modifiedService(ServiceReference reference, Object service) {
        T tracked = (T) getService(reference);
        Object property = reference.getProperty(Constants.OX_MODULE);
        int module = atoi(property);
        modifiedService(module, tracked, reference);
    }


    @Override
    public void removedService(ServiceReference reference, Object service) {
        T tracked = (T) getService(reference);
        Object property = reference.getProperty(Constants.OX_MODULE);
        int module = atoi(property);
        removedService(module, tracked, reference);
        context.ungetService(reference);
    }

    protected int atoi(Object property) {
        if(Integer.class.isInstance(property)) {
            return (Integer) property;
        }
        return Integer.parseInt(property.toString());
    }

    public void removedService(int module, T tracked, ServiceReference reference) {
        // Nothing to do

    }

    public void addingService(int module, T tracked, ServiceReference reference) {
        // Nothing to do

    }

    public void modifiedService(int module, T tracked, ServiceReference reference) {
        // Nothing to do

    }


}
